@@ -20,7 +20,7 @@
 #include "k3bfilesplitter.h"
 #include "k3b_i18n.h"
 
-#include <KCodecs/KCodecs>
+#include <KCodecs>
 
 #include <QCryptographicHash>
 #include <QDebug>
