@@ -36,7 +36,7 @@ namespace K3b {
         
     public:
         explicit ExternalBinParamsModel( ExternalBinManager* manager, QObject* parent = 0 );
-        ~ExternalBinParamsModel();
+        ~ExternalBinParamsModel() override;
         
         /**
          * Reloads programs from ExternalBinManager and updates the model
@@ -51,13 +51,13 @@ namespace K3b {
         ExternalProgram* programForIndex( const QModelIndex& index ) const;
         QModelIndex indexForProgram( ExternalProgram* program, int column = ProgramColumn ) const;
         
-        virtual Qt::ItemFlags flags( const QModelIndex& index ) const;
-        virtual QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const;
-        virtual bool setData( const QModelIndex& index, const QVariant& value, int role = Qt::EditRole );
-        virtual int columnCount( const QModelIndex& parent = QModelIndex() ) const;
-        virtual int rowCount( const QModelIndex& parent = QModelIndex() ) const;
-        virtual QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const;
-        virtual QModelIndex buddy( const QModelIndex& index ) const;
+        Qt::ItemFlags flags( const QModelIndex& index ) const override;
+        QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const override;
+        bool setData( const QModelIndex& index, const QVariant& value, int role = Qt::EditRole ) override;
+        int columnCount( const QModelIndex& parent = QModelIndex() ) const override;
+        int rowCount( const QModelIndex& parent = QModelIndex() ) const override;
+        QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const override;
+        QModelIndex buddy( const QModelIndex& index ) const override;
         
     private:
         class Private;
