@@ -28,7 +28,7 @@ class VideoDVDTitleModel : public QAbstractTableModel
 
 public:
     explicit VideoDVDTitleModel( QObject* parent = 0 );
-    ~VideoDVDTitleModel();
+    ~VideoDVDTitleModel() override;
 
     enum Columns {
         TitleColumn = 0,
@@ -51,13 +51,13 @@ public:
     void setVideoDVD( const VideoDVD::VideoDVD& dvd );
     QList<int> selectedTitles() const;
 
-    virtual Qt::ItemFlags flags( const QModelIndex& index ) const;
-    virtual QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const;
-    virtual bool setData( const QModelIndex& index, const QVariant& value, int role = Qt::EditRole );
-    virtual QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const;
-    virtual int rowCount( const QModelIndex& parent = QModelIndex() ) const;
-    virtual int columnCount( const QModelIndex& parent = QModelIndex() ) const;
-    virtual QModelIndex buddy( const QModelIndex& index ) const;
+    Qt::ItemFlags flags( const QModelIndex& index ) const override;
+    QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const override;
+    bool setData( const QModelIndex& index, const QVariant& value, int role = Qt::EditRole ) override;
+    QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const override;
+    int rowCount( const QModelIndex& parent = QModelIndex() ) const override;
+    int columnCount( const QModelIndex& parent = QModelIndex() ) const override;
+    QModelIndex buddy( const QModelIndex& index ) const override;
 
 public Q_SLOTS:
     void checkAll();
